import React, { FC, useEffect, useState } from 'react';
import { FlatList as List, SafeAreaView, View } from 'react-native';
import { Input } from '../Input';
import { styles } from './styles';
import { Item, ItemData } from './item';
import { useGetRegionsWithFlagQuery } from '../../modules/auth/regions/queries/use-post-get-regions';

type Props = {
  itemObject: (object: any) => void;
};

//TODO: rework to generic types + custom props

export const FlatList: FC<Props> = ({ itemObject }) => {
  const [selectedObject, setSelectedObject] = useState<{ name: string; id: number }>();
  const [search, setSearch] = useState('');
  const [filteredData, setFilteredData] = useState<ItemData[]>([]);
  const [masterData, setMasterData] = useState<ItemData[]>([]);

  const { data } = useGetRegionsWithFlagQuery(true);

  useEffect(() => {
    if (data) {
      setFilteredData(data.data);
      setMasterData(data.data);
    }
  }, [data]);

  const selectItem = (object: { name: string; id: number }) => {
    itemObject(object);
    setSelectedObject(object);
  };

  const searchFilter = (text: string) => {
    if (text) {
      const newData = masterData.filter((item) => {
        const itemData = item.name ? item.name.toLowerCase() : ''.toLowerCase();
        const textData = text.toLowerCase();
        return itemData.indexOf(textData) > -1;
      });
      setFilteredData(newData);
      setSearch(text);
    } else {
      setFilteredData(masterData);
      setSearch(text);
    }
  };

  const renderItem = ({ item }: { item: ItemData }) => {
    const selected = item.id === selectedObject?.id;

    const backgroundColor = selected ? '#FAFAFA' : 'white';

    return (
      <Item
        selected={selected}
        item={item}
        onPress={() => selectItem(item)}
        backgroundColor={backgroundColor}
      />
    );
  };

  return (
    <SafeAreaView style={styles.container}>
      <View style={{ marginTop: 10 }}>
        <Input
          inputMode={'search'}
          placeholder={'Search'}
          onChange={(text) => searchFilter(text)}
          value={search}
        />
      </View>
      <List
        data={filteredData}
        renderItem={renderItem}
        keyExtractor={(item) => item.id.toString()}
        extraData={selectedObject}
      />
    </SafeAreaView>
  );
};
